@@ -14,6 +14,8 @@ from sky_api_client.entity import event_participant_fee_payment  # noqa: F401
 from sky_api_client.entity import event_participant_donation  # noqa: F401
 from sky_api_client.entity import gender  # noqa: F401
 from sky_api_client.entity import gift  # noqa: F401
+from sky_api_client.entity import gift_batch  # noqa: F401
+from sky_api_client.entity import gift_batch_gift  # noqa: F401
 from sky_api_client.entity import online_presence  # noqa: F401
 from sky_api_client.entity import phone  # noqa: F401
 from sky_api_client.entity import suffix  # noqa: F401
